gnunet-svn
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[taler-exchange] 36/124: store provider_name, instead of provider_sectio


From: gnunet
Subject: [taler-exchange] 36/124: store provider_name, instead of provider_section
Date: Tue, 17 Sep 2024 21:27:28 +0200

This is an automated email from the git hooks/post-receive script.

grothoff pushed a commit to tag cg-aml-branch-compiles
in repository exchange.

commit f15e8e435b5772ba19c67b97bab4edb185d48e0c
Author: Christian Grothoff <christian@grothoff.org>
AuthorDate: Tue May 14 10:27:11 2024 +0200

    store provider_name, instead of provider_section
---
 src/exchange/taler-exchange-httpd_common_kyc.c          | 17 +++++++++--------
 src/exchange/taler-exchange-httpd_common_kyc.h          |  8 ++++----
 src/exchange/taler-exchange-httpd_reserves_attest.c     |  6 +++---
 src/exchange/taler-exchange-httpd_reserves_get_attest.c |  4 ++--
 4 files changed, 18 insertions(+), 17 deletions(-)

diff --git a/src/exchange/taler-exchange-httpd_common_kyc.c 
b/src/exchange/taler-exchange-httpd_common_kyc.c
index 6d6bd260e..141f99841 100644
--- a/src/exchange/taler-exchange-httpd_common_kyc.c
+++ b/src/exchange/taler-exchange-httpd_common_kyc.c
@@ -51,9 +51,9 @@ struct TEH_KycAmlTrigger
   uint64_t process_row;
 
   /**
-   * name of the configuration section of the logic that was run
+   * name of the provider with the logic that was run
    */
-  char *provider_section;
+  char *provider_name;
 
   /**
    * set to user ID at the provider, or NULL if not supported or unknown
@@ -161,6 +161,7 @@ kyc_aml_finished (void *cls,
     &kat->account_id,
     birthday,
     GNUNET_TIME_timestamp_get (),
+    kat->provider_name,
     kat->provider_user_id,
     kat->provider_legitimization_id,
     kat->expiration,
@@ -197,7 +198,7 @@ struct TEH_KycAmlTrigger *
 TEH_kyc_finished (const struct GNUNET_AsyncScopeId *scope,
                   uint64_t process_row,
                   const struct TALER_PaytoHashP *account_id,
-                  const char *provider_section,
+                  const char *provider_name,
                   const char *provider_user_id,
                   const char *provider_legitimization_id,
                   struct GNUNET_TIME_Absolute expiration,
@@ -213,8 +214,8 @@ TEH_kyc_finished (const struct GNUNET_AsyncScopeId *scope,
   kat->scope = *scope;
   kat->process_row = process_row;
   kat->account_id = *account_id;
-  kat->provider_section
-    = GNUNET_strdup (provider_section);
+  kat->provider_name
+    = GNUNET_strdup (provider_name);
   if (NULL != provider_user_id)
     kat->provider_user_id
       = GNUNET_strdup (provider_user_id);
@@ -253,7 +254,7 @@ TEH_kyc_finished_cancel (struct TEH_KycAmlTrigger *kat)
     TALER_JSON_external_conversion_stop (kat->kyc_aml);
     kat->kyc_aml = NULL;
   }
-  GNUNET_free (kat->provider_section);
+  GNUNET_free (kat->provider_name);
   GNUNET_free (kat->provider_user_id);
   GNUNET_free (kat->provider_legitimization_id);
   json_decref (kat->attributes);
@@ -269,7 +270,7 @@ TEH_kyc_finished_cancel (struct TEH_KycAmlTrigger *kat)
 bool
 TEH_kyc_failed (uint64_t process_row,
                 const struct TALER_PaytoHashP *account_id,
-                const char *provider_section,
+                const char *provider_name,
                 const char *provider_user_id,
                 const char *provider_legitimization_id)
 {
@@ -279,7 +280,7 @@ TEH_kyc_failed (uint64_t process_row,
     TEH_plugin->cls,
     process_row,
     account_id,
-    provider_section,
+    provider_name,
     provider_user_id,
     provider_legitimization_id);
   GNUNET_break (qs >= 0);
diff --git a/src/exchange/taler-exchange-httpd_common_kyc.h 
b/src/exchange/taler-exchange-httpd_common_kyc.h
index 8198679c9..e391c8d3b 100644
--- a/src/exchange/taler-exchange-httpd_common_kyc.h
+++ b/src/exchange/taler-exchange-httpd_common_kyc.h
@@ -61,7 +61,7 @@ struct TEH_KycAmlTrigger;
  * @param scope the HTTP request logging scope
  * @param process_row legitimization process the webhook was about
  * @param account_id account the webhook was about
- * @param provider_section name of the configuration section of the logic that 
was run
+ * @param provider_name name of the provider with the logic that was run
  * @param provider_user_id set to user ID at the provider, or NULL if not 
supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the 
provider, or NULL if not supported or unknown
  * @param expiration until when is the KYC check valid
@@ -76,7 +76,7 @@ struct TEH_KycAmlTrigger *
 TEH_kyc_finished (const struct GNUNET_AsyncScopeId *scope,
                   uint64_t process_row,
                   const struct TALER_PaytoHashP *account_id,
-                  const char *provider_section,
+                  const char *provider_name,
                   const char *provider_user_id,
                   const char *provider_legitimization_id,
                   struct GNUNET_TIME_Absolute expiration,
@@ -102,7 +102,7 @@ TEH_kyc_finished_cancel (struct TEH_KycAmlTrigger *kat);
  *
  * @param process_row legitimization process the webhook was about
  * @param account_id account the webhook was about
- * @param provider_section name of the configuration section of the logic that 
was run
+ * @param provider_name name KYC provider with the logic that was run
  * @param provider_user_id set to user ID at the provider, or NULL if not 
supported or unknown
  * @param provider_legitimization_id set to legitimization process ID at the 
provider, or NULL if not supported or unknown
  * @return true on success, false if updating the database failed
@@ -110,7 +110,7 @@ TEH_kyc_finished_cancel (struct TEH_KycAmlTrigger *kat);
 bool
 TEH_kyc_failed (uint64_t process_row,
                 const struct TALER_PaytoHashP *account_id,
-                const char *provider_section,
+                const char *provider_name,
                 const char *provider_user_id,
                 const char *provider_legitimization_id);
 
diff --git a/src/exchange/taler-exchange-httpd_reserves_attest.c 
b/src/exchange/taler-exchange-httpd_reserves_attest.c
index 7bbebaad7..db3ff617a 100644
--- a/src/exchange/taler-exchange-httpd_reserves_attest.c
+++ b/src/exchange/taler-exchange-httpd_reserves_attest.c
@@ -37,7 +37,7 @@
  * checking the request timestamp?
  */
 #define TIMESTAMP_TOLERANCE \
-  GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 15)
+        GNUNET_TIME_relative_multiply (GNUNET_TIME_UNIT_MINUTES, 15)
 
 
 /**
@@ -157,7 +157,7 @@ reply_reserve_attest_success (struct MHD_Connection 
*connection,
  *
  * @param cls our `struct ReserveAttestContext *`
  * @param h_payto account for which the attribute data is stored
  * @param provider_section provider that must be checked
  * @param collection_time when was the data collected
  * @param expiration_time when does the data expire
  * @param enc_attributes_size number of bytes in @a enc_attributes
@@ -166,7 +166,7 @@ reply_reserve_attest_success (struct MHD_Connection 
*connection,
 static void
 kyc_process_cb (void *cls,
                 const struct TALER_PaytoHashP *h_payto,
-                const char *provider_section,
+                const char *provider_name,
                 struct GNUNET_TIME_Timestamp collection_time,
                 struct GNUNET_TIME_Timestamp expiration_time,
                 size_t enc_attributes_size,
@@ -157,7 +157,7 @@ reply_reserve_attest_success (struct MHD_Connection 
  * @param cls our `struct ReserveAttestContext *`
  * @param h_payto account for which the attribute data is stored
- * @param provider_section provider that must be checked
+ * @param provider_name provider that must be checked
  * @param collection_time when was the data collected
  * @param expiration_time when does the data expire
diff --git a/src/exchange/taler-exchange-httpd_reserves_get_attest.c 
b/src/exchange/taler-exchange-httpd_reserves_get_attest.c
index ae983682a..53eff1f5c 100644
--- a/src/exchange/taler-exchange-httpd_reserves_get_attest.c
+++ b/src/exchange/taler-exchange-httpd_reserves_get_attest.c
@@ -63,7 +63,7 @@ struct ReserveAttestContext
  *
  * @param cls our `struct ReserveAttestContext *`
  * @param h_payto account for which the attribute data is stored
  * @param provider_section provider that must be checked
  * @param collection_time when was the data collected
  * @param expiration_time when does the data expire
  * @param enc_attributes_size number of bytes in @a enc_attributes
@@ -72,7 +72,7 @@ struct ReserveAttestContext
 static void
 kyc_process_cb (void *cls,
                 const struct TALER_PaytoHashP *h_payto,
-                const char *provider_section,
+                const char *provider_name,
                 struct GNUNET_TIME_Timestamp collection_time,
                 struct GNUNET_TIME_Timestamp expiration_time,
                 size_t enc_attributes_size,
@@ -63,7 +63,7 @@ struct ReserveAttestContext
  * @param cls our `struct ReserveAttestContext *`
  * @param h_payto account for which the attribute data is stored
- * @param provider_section provider that must be checked
+ * @param provider_name provider that must be checked
  * @param collection_time when was the data collected
  * @param expiration_time when does the data expire

-- 
To stop receiving notification emails like this one, please contact
gnunet@gnunet.org.



reply via email to

[Prev in Thread] Current Thread [Next in Thread]